import { SchemyOptions, SchemyPlugin, SchemyPluginEvent, SchemySchema, SchemyTyped, ValidationError } from "./types";
export declare class Schemy {
    static plugins: SchemyPlugin[];
    schemaParsed: boolean;
    validationErrors: ValidationError[];
    flex: boolean;
    data: any;
    schema: SchemySchema;
    /**
     * Extend Schemy functionality with plugins
     *
     * @param plugins Array of plugins or just one plugin
     */
    static extend(plugins: SchemyPlugin | SchemyPlugin[]): void;
    static getVersion(): string;
    /**
     * Creates a Schemy instance with typed non strict Schema
     *
     * @param schema Schema object
     * @param settings Schemy options
     * @returns Schema object
     */
    static schema<Type>(schema: SchemyTyped<Type>): Schemy;
    /**
     * Creates a Schemy instance with typed strict Schema
     *
     * @param schema Schema object
     * @returns Schema object
     */
    static strict<Type>(schema: SchemyTyped<Type>): Schemy;
    /**
     * Invokes the plugin callbacks for the event
     *
     * @param event Event to trigger
     * @param body Object to pass as a parameter to the plugin
     */
    static triggerEvent(event: SchemyPluginEvent, body: any): void;
    /**
     * Async validates an object against a schema and returns the body
     *
     * @param body Object to validate
     * @param schema Schemy instance or raw schema to validate against to
     * @param includeAll Include properties not declared in schema, defaults to false
     * @param orderBody Order the body based on the schema, defaults to false
     */
    static validate<OutputType>(body: any, schema: Schemy | SchemySchema, includeAll?: boolean, orderBody?: boolean): Promise<OutputType>;
    constructor(schema: SchemySchema, settings?: SchemyOptions);
    /**
     * Validates data against this schema
     * If you also want the input data, use the static validate method instead
     *
     * @param data Object to validate agains the schema
     * @returns True if validated correctly, false otherwise
     */
    validate(data: any): boolean;
    /**
     * Get all the validation errors from the last validation
     *
     * @returns Array with string of errors
     */
    getValidationErrors(): string[];
    getGroupedValidationErrors(): ValidationError[];
    /**
     * Get the data provided in the last validation
     *
     * @param includeAll Include properties not declared in schema
     * @param orderBody Order the body based on the schema
     * @returns Last validated data
     */
    getBody<OutputType>(includeAll?: boolean, orderBody?: boolean): OutputType;
}
